import React from 'react';
import Taro from '@tarojs/taro';
import { View } from '@tarojs/components';
import { Notify, Field, Cell, CellGroup, Uploader } from '@antmjs/vantui';
import Page from '@/layouts/index';
import LocType from '@/components/locType';
import IssueType from '@/components/issueType';
import Map from '@/components/map';
import getAuthorize from '@/utils/authorize';
import { ROLE_INSPECTOR } from '@/utils/user';
import mapIcon from '@/assets/icons/marker.png';

export default (props) => {

  const [showLocType, setShowLocType] = React.useState(false);
  const [showIssueType, setShowIssueType] = React.useState(false);
  const [loc, setLoc] = React.useState();
  const [locType, setLocType] = React.useState();
  const [issueType, setIssueType] = React.useState();
  const [address, setAddress] = React.useState();

  const onLocTypeChange = (_, it) => {
    setLocType(it);
    setShowLocType(false);
  }
  const onIssueTypeChange = (_, it) => {
    setIssueType(it);
    setShowIssueType(false);
  }
  
  React.useMemo(() => {
    getAuthorize('scope.userLocation').then(() => {
      Taro.getLocation({
        success(res) {
          setLoc(`${res.longitude},${res.latitude}`);
        },
        fail() {
          Notify.show({
            message: '获取位置失败, 请退出重试',
            type: 'warning',
          })
        }
      });
    }).catch((err) => {
      Notify.show({
        message: '未能获取位置, 程序部分功能将不能正常使用',
        type: 'warning',
      })
    });
  }, []);

  return (
    <Page roles={[ROLE_INSPECTOR]}>
      <LocType
        show={showLocType}
        value={locType?.typeId}
        onCancel={() => setShowLocType(false)}
        onChange={onLocTypeChange}
      />

      <IssueType
        show={showIssueType}
        value={issueType?.typeId}
        onCancel={() => setShowIssueType(false)}
        onChange={onIssueTypeChange}
      />

      <Map location={loc} />

      <Field
        value={address}
        leftIcon={mapIcon}
        placeholder="请输入地址"
        onChange={e => setAddress(e.detail)}
      />

      <CellGroup style={{marginTop: '20px'}}>
        <Cell
          isLink
          title="点位"
          value={locType?.name}
          onClick={() => setShowLocType(true)}
        />

        <Cell title="问题描述" border={false} />

        <Field
          type="textarea"
          placeholder="请输入问题描述"
          autosize={{ minHeight: '120px' }}
        />
      </CellGroup>
      
      <Cell
        isLink
        title="问题分类"
        style={{marginTop: '20px'}}
        value={issueType?.name}
        onClick={() => setShowIssueType(true)}
      />

      
      <CellGroup style={{marginTop: '20px'}}>        
        <Cell title="拍照" border={false} />

        <Cell
          renderTitle={
            <Uploader
              deletable
            />
          }
        />
      </CellGroup>
    </Page>
  )
}
